pub struct HighlightTheme {
pub selected_color: String,
pub hover_color: String,
pub error_color: String,
pub warning_color: String,
}Expand description
Highlight theme configuration.
Fields
selected_color: StringThe color used for selected elements (hex string).
hover_color: StringThe color used for elements on hover (hex string).
error_color: StringThe color used for elements in an error state (hex string).
warning_color: StringThe color used for elements in a warning state (hex string).