pub struct TreeLayout { /* private fields */ }Expand description
Tree layout engine.
Implementations
Sourceimpl TreeLayout
impl TreeLayout
Sourcepub fn with_algorithm(self, algorithm: TreeLayoutAlgorithm) -> Self
pub fn with_algorithm(self, algorithm: TreeLayoutAlgorithm) -> Self
Sets the layout algorithm and returns the modified engine.
Sourcepub fn with_config(self, config: TreeLayoutConfig) -> Self
pub fn with_config(self, config: TreeLayoutConfig) -> Self
Sets the layout configuration and returns the modified engine.
Sourcepub fn visualize(&self, tree: &TreeNode) -> Result<String>
pub fn visualize(&self, tree: &TreeNode) -> Result<String>
Visualizes the tree as an SVG string.
Sourcepub fn layout_tree(&self, tree: &TreeNode) -> Result<Layout>
pub fn layout_tree(&self, tree: &TreeNode) -> Result<Layout>
Calculates the layout for the given tree.